@@ -75,15 +75,30 @@
 #include "conf.h"
 #include "config.h"
 
-extern int yylineno;
+extern int yylex (void);
+extern int yyget_lineno (void);
+
+/* Defines needed for a pure reentrant parser/lexer.
+   These are dsiabled for now due to failure to realize.
+   #define YYLEX_PARAM   foo
+ */
+#define YYPARSE_PARAM list
+#define yylineno      yyget_lineno ()
+
+int yyerror (char *s)
+{
+  fprintf (stderr, "ERROR: %s\n", s);
+
+  return -1;
+}
 
 #define conf_set(key,value)				\
-   if (conf_set_value (key, value))			\
-     fprintf (stderr,					\
-	      "Error on line %d in config file, "	\
-	      "%s is not a valid identifier.\n",	\
-	      yylineno, key)
-
+  if (conf_set_value ((param_t *)list, key, value))	\
+    fprintf (stderr,					\
+	     "Error on line %d in config file, "	\
+	     "%s is not a valid identifier.\n",		\
+	     yylineno, key)
+ 
 
 
 /* Enabling traces.  */
@@ -100,12 +115,12 @@ extern int yylineno;
 #endif
 
 #if ! defined (YYSTYPE) && ! defined (YYSTYPE_IS_DECLARED)
-#line 20 "conf/parser.y"
+#line 36 "conf/parser.y"
 typedef union YYSTYPE {
 	char *str;
 } YYSTYPE;
 /* Line 191 of yacc.c.  */
-#line 109 "parser.c"
+#line 124 "parser.c"
 # define yystype YYSTYPE /* obsolescent; will be withdrawn */
 # define YYSTYPE_IS_DECLARED 1
 # define YYSTYPE_IS_TRIVIAL 1
@@ -117,7 +132,7 @@ typedef union YYSTYPE {
 
 
 /* Line 214 of yacc.c.  */
-#line 121 "parser.c"
+#line 136 "parser.c"
 
 #if ! defined (yyoverflow) || YYERROR_VERBOSE
 
@@ -284,7 +299,7 @@ static const yysigned_char yyrhs[] =
 /* YYRLINE[YYN] -- source line where rule number YYN was defined.  */
 static const unsigned char yyrline[] =
 {
-       0,    29,    29,    30,    33,    34,    37,    39
+       0,    45,    45,    46,    49,    50,    53,    55
 };
 #endif
 
@@ -982,13 +997,13 @@ yyreduce:
   switch (yyn)
     {
         case 6:
-#line 37 "conf/parser.y"
+#line 53 "conf/parser.y"
     {/* printf ("\nBison(ID:%s)(ARG:%s)", $1, $3); */
                                  conf_set (yyvsp[-2].str, yyvsp[0].str);}
     break;
 
   case 7:
-#line 39 "conf/parser.y"
+#line 55 "conf/parser.y"
     {/* printf ("%s(%s)\n", $1, $2); */
                                  conf_set (yyvsp[-1].str, yyvsp[0].str);}
     break;
@@ -997,7 +1012,7 @@ yyreduce:
     }
 
 /* Line 999 of yacc.c.  */
-#line 1001 "parser.c"
+#line 1016 "parser.c"
 
   yyvsp -= yylen;
   yyssp -= yylen;
@@ -1191,13 +1206,7 @@ yyreturn:
 }
 
 
-#line 43 "conf/parser.y"
+#line 59 "conf/parser.y"
 
 
-int yyerror (char *s)
-{
-  fprintf (stderr, "ERROR: %s\n", s);
-
-  return -1;
-}
 
